# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from systemathics.apis.services.tick.v1 import tick_quotes_pb2 as systemathics_dot_apis_dot_services_dot_tick_dot_v1_dot_tick__quotes__pb2


class TickQuotesServiceStub(object):
    """Called to request tick by tick normalized quotes data (MBO).
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.TickQuotes = channel.unary_stream(
                '/systemathics.apis.services.tick.v1.TickQuotesService/TickQuotes',
                request_serializer=systemathics_dot_apis_dot_services_dot_tick_dot_v1_dot_tick__quotes__pb2.TickQuotesRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_tick_dot_v1_dot_tick__quotes__pb2.TickQuotesResponse.FromString,
                )


class TickQuotesServiceServicer(object):
    """Called to request tick by tick normalized quotes data (MBO).
    """

    def TickQuotes(self, request, context):
        """Get tick by tick normalized quotes 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TickQuotesServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'TickQuotes': grpc.unary_stream_rpc_method_handler(
                    servicer.TickQuotes,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_tick_dot_v1_dot_tick__quotes__pb2.TickQuotesRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_tick_dot_v1_dot_tick__quotes__pb2.TickQuotesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'systemathics.apis.services.tick.v1.TickQuotesService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TickQuotesService(object):
    """Called to request tick by tick normalized quotes data (MBO).
    """

    @staticmethod
    def TickQuotes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/systemathics.apis.services.tick.v1.TickQuotesService/TickQuotes',
            systemathics_dot_apis_dot_services_dot_tick_dot_v1_dot_tick__quotes__pb2.TickQuotesRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_tick_dot_v1_dot_tick__quotes__pb2.TickQuotesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/stream.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-systemathics/apis/type/shared/v1/stream.proto\x12 systemathics.apis.type.shared.v1*Z\n\x06Stream\x12\x16\n\x12STREAM_UNSPECIFIED\x10\x00\x12\x16\n\x12STREAM_FIELDS_ONLY\x10\x01\x12 \n\x1cSTREAM_MARKETBOOK_AND_FIELDS\x10\x02\x42\xd8\x01\n$com.systemathics.apis.type.shared.v1B\x0bStreamProtoP\x01\xa2\x02\x04SATS\xaa\x02 Systemathics.Apis.Type.Shared.V1\xca\x02 Systemathics\\Apis\\Type\\Shared\\V1\xe2\x02,Systemathics\\Apis\\Type\\Shared\\V1\\GPBMetadata\xea\x02$Systemathics::Apis::Type::Shared::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.type.shared.v1.stream_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$com.systemathics.apis.type.shared.v1B\013StreamProtoP\001\242\002\004SATS\252\002 Systemathics.Apis.Type.Shared.V1\312\002 Systemathics\\Apis\\Type\\Shared\\V1\342\002,Systemathics\\Apis\\Type\\Shared\\V1\\GPBMetadata\352\002$Systemathics::Apis::Type::Shared::V1'
  _globals['_STREAM']._serialized_start=83
  _globals['_STREAM']._serialized_end=173
# @@protoc_insertion_point(module_scope)
